==> order-center-api-3.2.3-CLOUD-DEV-20241106.091901-17-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInvoiceBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInvoiceBo
 * 说明:
 * 时间:2022/3/10 12:24
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspInvoiceBo implements Serializable {


    private static final long serialVersionUID = 7952638696358451825L;

    
    private Long id;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 发票类型    1 普票   2 专票
     */
    private Integer invoiceType;

    /**
     * 发票类型翻译
     */
    private String invoiceTypeStr;

    /**发票类别：1电子，2纸质，默认1*/
    private Integer invoceCategory;

    /**发票类别翻译*/
    private String invoceCategoryStr;

    /**购买人或公司名称*/
    private String buyerName;

    /**固定电话*/
    private String fixPhone;

    /**税号*/
    private String invoiceNo;

    /**单位地址*/
    private String companyAddress;

    /**收货地址ID*/
    private Long contactId;

    /**开户银行*/
    private String depositBank;

    /**银行账户*/
    private String bankAccount;

    /**发票号*/
    private String invoiceSn;

    /**发票url*/
    private String invoiceUrl;

    /**联系人电话*/
    private String relaPhone;

    /**联系人邮箱*/
    private String relaEmail;

    /**添加外部发票id*/
    private String outInvoiceId;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**创建人*/
    private String createOperName;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**更新人*/
    private String updateOperName;

    /**
     * 备注
     */
    private String remark;

}

==> order-center-api-3.3.0-CLOUD-DEV-20251117.080724-2-sources.jar: com/tydic/dyc/oc/service/saleorder/bo/UocGetSaleOrderDetailServiceRspInvoiceBo.java <==
package com.tydic.dyc.oc.service.saleorder.bo;

import com.tydic.dyc.base.core.dictionary.annotation.DictField;
import com.tydic.dyc.oc.constants.UocDicConstant;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocGetSaleOrderDetailServiceRspInvoiceBo
 * 说明:
 * 时间:2022/3/10 12:24
 * 作者:田桂银
 */
@Data
@EqualsAndHashCode(callSuper=false)
public class UocGetSaleOrderDetailServiceRspInvoiceBo implements Serializable {


    private static final long serialVersionUID = 7952638696358451825L;

    
    private Long id;

    /**
     * 订单id
     */
    private Long orderId;

    /**
     * 发票类型    1 普票   2 专票
     */
    @DictField(busiCenter = "UOC_PRO",pCode = UocDicConstant.INVOICE_TYPE.P_CODE)
    private Integer invoiceType;

    /**
     * 发票类型翻译
     */
    private String invoiceTypeStr;

    /**发票类别：1电子，2纸质，默认1*/
    @DictField(busiCenter = "UOC_PRO",pCode = UocDicConstant.INVOICE_CATEGORY.P_CODE)
    private Integer invoceCategory;

    /**发票类别翻译*/
    private String invoceCategoryStr;

    /**购买人或公司名称*/
    private String buyerName;

    /**固定电话*/
    private String fixPhone;

    /**税号*/
    private String invoiceNo;

    /**单位地址*/
    private String companyAddress;

    /**收货地址ID*/
    private Long contactId;

    /**开户银行*/
    private String depositBank;

    /**银行账户*/
    private String bankAccount;

    /**发票号*/
    private String invoiceSn;

    /**发票url*/
    private String invoiceUrl;

    /**联系人电话*/
    private String relaPhone;

    /**联系人邮箱*/
    private String relaEmail;

    /**添加外部发票id*/
    private String outInvoiceId;

    /**创建时间*/
    private Date createTime;

    /**创建工号*/
    private String createOperId;

    /**创建人*/
    private String createOperName;

    /**更新时间*/
    private Date updateTime;

    /**更新工号*/
    private String updateOperId;

    /**更新人*/
    private String updateOperName;

    /**
     * 备注
     */
    private String remark;

}
